@@ -1,23 +1,35 @@
+"""
+Main CLI entrypoint.
+"""
 import sys
 
 
 def print_info() -> None:
+    """
+    Print package info to stdout.
+    """
     print(
-        "Type annotations for boto3.Neptune 1.17.71\n"
-        "Version:         1.17.71.post1\n"
-        "Builder version: 4.12.0\n"
+        "Type annotations for boto3.Neptune 1.18.0\n"
+        "Version:         1.18.0\n"
+        "Builder version: 5.0.0\n"
         "Docs:            https://pypi.org/project/mypy-boto3-neptune/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/neptune.html#Neptune\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.71.post1")
+    """
+    Print package version to stdout.
+    """
+    print("1.18.0")
 
 
 def main() -> None:
+    """
+    Main CLI entrypoint.
+    """
     if "--version" in sys.argv:
         return print_version()
     print_info()
